pub struct ProgramVersion {
pub version: u8,
pub bump: u8,
pub updated: i64,
}Fields
version: u8bump: u8updated: i64Trait Implementations
Sourceimpl BorshDeserialize for ProgramVersion
impl BorshDeserialize for ProgramVersion
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl CarbonDeserialize for ProgramVersion
impl CarbonDeserialize for ProgramVersion
const DISCRIMINATOR: &'static [u8]
fn deserialize(data: &[u8]) -> Option<Self>
Sourceimpl Clone for ProgramVersion
impl Clone for ProgramVersion
Sourcefn clone(&self) -> ProgramVersion
fn clone(&self) -> ProgramVersion
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ProgramVersion
impl Debug for ProgramVersion
Sourceimpl<'de> Deserialize<'de> for ProgramVersion
impl<'de> Deserialize<'de> for ProgramVersion
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Hash for ProgramVersion
impl Hash for ProgramVersion
Sourceimpl PartialEq for ProgramVersion
impl PartialEq for ProgramVersion
Sourceimpl Serialize for ProgramVersion
impl Serialize for ProgramVersion
impl Eq for ProgramVersion
impl StructuralPartialEq for ProgramVersion