pub struct UpdateProgramVersion {
pub version: u8,
}Fields
version: u8Trait Implementations
Sourceimpl ArrangeAccounts for UpdateProgramVersion
impl ArrangeAccounts for UpdateProgramVersion
type ArrangedAccounts = UpdateProgramVersionInstructionAccounts
fn arrange_accounts(accounts: &[AccountMeta]) -> Option<Self::ArrangedAccounts>
Sourceimpl BorshDeserialize for UpdateProgramVersionwhere
u8: BorshDeserialize,
impl BorshDeserialize for UpdateProgramVersionwhere
u8: BorshDeserialize,
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl CarbonDeserialize for UpdateProgramVersion
impl CarbonDeserialize for UpdateProgramVersion
const DISCRIMINATOR: &'static [u8]
fn deserialize(data: &[u8]) -> Option<Self>
Sourceimpl Clone for UpdateProgramVersion
impl Clone for UpdateProgramVersion
Sourcefn clone(&self) -> UpdateProgramVersion
fn clone(&self) -> UpdateProgramVersion
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for UpdateProgramVersion
impl Debug for UpdateProgramVersion
Sourceimpl<'de> Deserialize<'de> for UpdateProgramVersion
impl<'de> Deserialize<'de> for UpdateProgramVersion
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Hash for UpdateProgramVersion
impl Hash for UpdateProgramVersion
Sourceimpl PartialEq for UpdateProgramVersion
impl PartialEq for UpdateProgramVersion
Sourceimpl Serialize for UpdateProgramVersion
impl Serialize for UpdateProgramVersion
impl Eq for UpdateProgramVersion
impl StructuralPartialEq for UpdateProgramVersion